#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MZERO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MZERO_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mzero.hpp>

#endif
